@@ -11,3 +11,6 @@ from pygeoweaver.sc_run import *
 from pygeoweaver.server import *
 from pygeoweaver.sc_resetpassword import *
 from pygeoweaver.sc_help import *
+from pygeoweaver.sc_create import *
+from pygeoweaver.sc_sync import *
+from pygeoweaver.sc_find import *
